@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH. group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -63,6 +35,7 @@ import java.util.regex.PatternSyntaxException;
 import java.util.stream.Collectors;
 import com.amazonaws.services.s3.internal.BucketNameUtils;
 import com.openexchange.config.lean.LeanConfigurationService;
+import com.openexchange.config.lean.Property;
 import com.openexchange.configuration.ConfigurationExceptionCodes;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Strings;
@@ -156,18 +129,42 @@ public class S3ClientConfig {
         String defaultValue = defaultValueObj == null ? null : defaultValueObj.toString();
         Map<String, String> clientQualifier = getClientQualifier(getClientID());
         if (getClientScope().isShared()) {
-            return new ConfigProperty(property.getFQPropertyName(clientQualifier), configService.getProperty(property, clientQualifier));
+            return new ConfigProperty(property.getFQPropertyName(clientQualifier), getProperty(configService, property, clientQualifier));
         }
 
         Optional<S3Property> filestoreProperty = S3Property.of(property);
         if (filestoreProperty.isPresent()) {
             Map<String, String> filestoreQualifier = getFilestoreQualifier(filestoreID);
-            return new ConfigProperty(filestoreProperty.get().getFQPropertyName(filestoreQualifier), configService.getProperty(filestoreProperty.get(), filestoreQualifier));
+            return new ConfigProperty(filestoreProperty.get().getFQPropertyName(filestoreQualifier), getProperty(configService, filestoreProperty.get(), filestoreQualifier));
         }
 
         return new ConfigProperty(property.getFQPropertyName(clientQualifier), defaultValue);
     }
 
+    /**
+     * Gets the property values based on the default type and parses it to string
+     *
+     * @param configService The {@link LeanConfigurationService} to use
+     * @param prop The {@link Property} to get
+     * @param optionals The optionals
+     * @return The property value
+     */
+    private static String getProperty(LeanConfigurationService configService, Property prop, Map<String, String> optionals) {
+        if (prop.getDefaultValue() != null) {
+            Class<? extends Object> coerce = prop.getDefaultValue().getClass();
+            if (coerce.isAssignableFrom(Boolean.class)) {
+                return String.valueOf(configService.getBooleanProperty(prop, optionals));
+            } else if (coerce.isAssignableFrom(Integer.class)) {
+                return String.valueOf(configService.getIntProperty(prop, optionals));
+            } else if (coerce.isAssignableFrom(Long.class)) {
+                return String.valueOf(configService.getLongProperty(prop, optionals));
+            } else if (coerce.isAssignableFrom(Float.class)) {
+                return String.valueOf(configService.getFloatProperty(prop, optionals));
+            }
+        }
+        return configService.getProperty(prop, optionals);
+    }
+
     /**
      * Gets the property value for the most specific scope it is defined in.
      * If it is not defined and the default value is {@code null} or the empty string or
@@ -289,10 +286,10 @@ public class S3ClientConfig {
         contributors.add(I(configService.getIntProperty(S3Property.MAX_NUMBER_OF_MONITORED_CLIENTS)));
         for (S3ClientProperty property : S3ClientProperty.values()) {
             if (scope == S3ClientScope.SHARED) {
-                contributors.add(configService.getProperty(property, qualifierMap));
+                contributors.add(getProperty(configService, property, qualifierMap));
             } else {
                 contributors.add(S3Property.of(property)
-                    .map(p -> (Object) configService.getProperty(p, qualifierMap))
+                    .map(p -> (Object) getProperty(configService, p, qualifierMap))
                     .orElse(property.getDefaultValue()));
             }
         }
